%define ALD_Ver		2.0

#USE gcc-7.5.0

%define OrgName bash
%define mC_Version 1.2.4s

Name:         mC-%{OrgName}
License:      GPL
Summary:      The GNU Bourne-Again Shell (build static-uClibc)
Version:      4.4.23
Release:      %{mC_Version}.0

#Source: ftp://ftp.gnu.org/gnu/bash/

Source: %{OrgName}-4.4.18.tar.xz
Source2: bash-4.4.18-patches.tgz

%define DestDir /Embedded/mC/%{mC_Version}
%define _prefix /usr/mC/%{mC_Version}
%define _datadir /usr/share

# -----------------------------------------------------
%define auto_local %{_sourcedir}/AUTO_LOCAL-1.sh
%define have_auto_local %(if test -x %{auto_local} ; then echo 1 ; else echo 0 ; fi)

%if %{_target_cpu} == %{_build_cpu}
%define _srcrpmdir	%{_topdir}/SRPMS/%{ALD_Ver}/mC/%{mC_Version}
%define _CROSS 0
%else
# rpm --target=x86_64 -ba xxxxx.spec
%define _srcrpmdir	%{_topdir}/SRPMS/tmp
%define _CROSS 1
%endif

# -----------------------------------------------------

%if %{have_auto_local}
%define __os_install_post %{nil}
%endif

%if %{_CROSS}
%define CrossPath /cross/%{_target_cpu}
%else
%define CrossPath %{nil}
%endif

#------------------ CROSS DIR --------------------

%define target %{_arch}-linux-musl
%define docdir %{_defaultdocdir}/%{OrgName}

# ------------------- description ------------------------------------
%description
Bash is a sh-compatible command interpreter
build static musl-%{mC_Version}
#-------------------------------
%package help
Summary:      external help files for builtin documentation
%description help
external help files for builtin documentation
#-------------------------------
%package sh
Provides:     sh
Summary:      The GNU Bourne-Again Shell sh link
%description sh
The GNU Bourne-Again Shell sh link
#-------------------------------
%package info
Summary:      Info for %{OrgName}
%description info
Info for %{OrgName}
#-------------------------------
%package doc
Summary:      any docs and *.html for %{OrgName}
%description doc
any docs and *.html for %{OrgName}
#-------------------------------
%package bug
Summary:      bashbug - create a bug report and mail it to the bug address
%description bug
bashbug - create a bug report and mail it to the bug address

# ------------------- setup ------------------------------------------
%Prep
%setup -q -n %{OrgName}-4.4.18

tar -xzf %SOURCE2
patch -p0<patches/bash44-019
patch -p0<patches/bash44-020
patch -p0<patches/bash44-021
patch -p0<patches/bash44-022
patch -p0<patches/bash44-023

# ------------------- Build ------------------------------------------
%Build
export PATH=$PATH:%{CrossPath}%{_prefix}/bin
export GCC_NoHostPath=d

%if %{_arch} == "i386"
OPTFLAGS="-O2 -march=i586 -mpreferred-stack-boundary=2 -falign-functions=1 -falign-jumps=1 -falign-loops=1 -fomit-frame-pointer"
%endif
%if %{_arch} == "x86_64"
#798.5  96 OPTFLAGS="-O2 -mpreferred-stack-boundary=3"
#801.3  97 OPTFLAGS="-O2"
#793.9  95 OPTFLAGS="-O2 -mpreferred-stack-boundary=3 -fno-tree-loop-optimize -fno-tree-dominator-opts -fno-strength-reduce"
OPTFLAGS="-Os -fno-tree-loop-optimize -fno-tree-dominator-opts -fno-strength-reduce"
#689.3 116ms OPTFLAGS="-Os -fno-stack-protector"
#685.6 116ms OPTFLAGS="-Os -fno-tree-loop-optimize -fno-tree-dominator-opts -fno-strength-reduce -fno-stack-protector"
#682.4 116ms OPTFLAGS="-Os -mpreferred-stack-boundary=3 -fno-tree-loop-optimize -fno-tree-dominator-opts -fno-strength-reduce"
%endif
%if %{_arch} == "arm"
OPTFLAGS="%{optflags} -Os -munaligned-access"
%endif

OPTFLAGS="$OPTFLAGS -fno-asynchronous-unwind-tables -ffunction-sections -fdata-sections"
export CFLAGS="$OPTFLAGS -DNeXT -std=gnu99"
export LDFLAGS="-Wl,--gc-sections"
export CC="%{target}-gcc"
#export AR="%{target}-ar"
#export AR="%{target}-ar -curv"
#export RANLIB="%{target}-ranlib"

./configure \
%if %{_CROSS}
	--build=%{_build} \
	--host=%{target} \
%endif
	--exec-prefix= \
	--prefix=/usr \
	--libdir=%{_libdir} \
	--includedir=%{_includedir} \
	--enable-arith-for-command \
	--disable-bang-history \
	--disable-net-redirections \
	--disable-progcomp \
	--enable-readline \
	--disable-restricted \
	--disable-select \
	--disable-profiling \
	--enable-static-link \
	--disable-nls \
	--without-afs \
	--without-bash-malloc \
	--enable-multibyte \
	--disable-net-redirections \
	--enable-separate-helpfiles \
	--enable-glob-asciiranges-default \
	&>FConfigure_log.txt

make -j2 &>FMake_log.txt

# ------------------- Install ----------------------------------------
%Install
export PATH=$PATH:%{CrossPath}%{_prefix}/bin
export GCC_NoHostPath=d

rm -rf $RPM_BUILD_ROOT
mkdir -p %{_srcrpmdir}
mkdir -p $RPM_BUILD_ROOT%{docdir}

make DESTDIR=$RPM_BUILD_ROOT install &>FInstall_log.txt
ln -s /usr/share/doc/gpl-3.0.txt $RPM_BUILD_ROOT%{docdir}/COPYING
rm $RPM_BUILD_ROOT%{docdir}/CHANGES
rm -rf $RPM_BUILD_ROOT%{_infodir}/dir
ln -s bash $RPM_BUILD_ROOT/bin/sh

%if %{have_auto_local}
  %{auto_local} -build_cpu=%{_build_cpu} -target_cpu=%{_target_cpu} \
	-target_platform=%{target}-
%endif  # have_auto_local

# ------------------- Clean ------------------------------------------
%Clean
%if %{have_auto_local}
  %{auto_local} -build_cpu=%{_build_cpu} -target_cpu=%{_target_cpu} \
	-ALD_Ver=%{ALD_Ver} -RpmMovePath=%{DestDir} -tar_arg=bzip2
%endif  # have_auto_local

# ------------------- Cross Files ------------------------------------
%files
/bin/bash
%{_mandir}/man1/bash.1.gz
%{docdir}/COPYING
%{docdir}/README

%files sh
/bin/sh

%files help
%{_datadir}/bash

%files doc
%{docdir}/COMPAT
%{docdir}/FAQ
%{docdir}/INTRO
%{docdir}/NEWS
%{docdir}/POSIX
%{docdir}/RBASH
%{docdir}/*.html

%files info
%{_infodir}

%files bug
/bin/bashbug
%{_mandir}/man1/bashbug.1.gz
